Module paths

Module paths 

Shared path resolution for the Auths home directory.

All code that needs the ~/.auths directory should call auths_home_with_config (or the legacy shim auths_home) instead of hardcoding dirs::home_dir().join(".auths"). This enables multi-agent simulation and CI overrides via the AUTHS_HOME env var.

Enums

AuthsHomeError
Error returned when the Auths home directory cannot be resolved.

Functions

auths_home
Resolves the Auths home directory.
auths_home_with_config
Resolves the Auths home directory from an injected EnvironmentConfig.