Module device

Module device 

Device authorization policy.

This module implements the device authorization rules that determine whether a device attestation grants permission for a specific action.

Enums

Action
An action that requires authorization.

Functions

authorize_device
Authorize a device to perform an action.