Module network

Module network 

Network port and DID resolution.

Structs

RegistryResponse
Response from a registry POST operation.

Enums

NetworkError
Domain error for outbound network operations.
ResolutionError
Domain error for identity resolution operations.
ResolvedIdentity
Cryptographic material resolved from a decentralized identifier.

Traits

IdentityResolver
Resolves a decentralized identifier to its current cryptographic material.
RegistryClient
Fetches and pushes data to a remote registry service.
WitnessClient
Submits key events and queries receipts from the witness infrastructure.