Module continuity

Module continuity 

KEL continuity checking trait for key rotation verification.

This module defines the trait that auths-id implements to verify rotation continuity without auths-core depending on auths-id.

Structs

RotationProof
Proof that a key rotation is valid from a known state to a new state.

Traits

KelContinuityChecker
Trait for verifying rotation continuity from a pinned state to a presented key.