Module client

Module client 

SSH agent client for communicating with a running agent.

This module provides client functions to communicate with an SSH agent over a Unix domain socket, enabling passphrase-free signing operations.

Enums

AgentStatus
Status of the agent connection.

Functions

add_identity
Add an identity (private key) to the SSH agent.
agent_sign
Sign data using a key loaded in the SSH agent.
check_agent_status
Check the status of the SSH agent.
list_identities
List all identities (public keys) loaded in the agent.
remove_all_identities
Remove all identities (keys) from the SSH agent.