Application-level runtime API for managing the identity agent and keys.
Provides functions to interact with core components: secure key storage (KeyStorage),
cryptographic operations, the in-memory agent (AgentCore), and the agent listener.
Uses AgentHandle for lifecycle management of agent instances.
Also includes functions for interacting with the platform’s SSH agent (on macOS).
Structs
- KeyLoad
Status - Represents the result of trying to load a single key into the agent core.
- KeyRegistration
Status - Represents the status of registering a single key with the system SSH agent.
Enums
- Registration
Outcome - Represents the outcome of attempting to register a key with the system SSH agent.
Functions
- agent_
sign_ with_ handle - Signs a message using a key currently loaded in the specified agent handle.
- clear_
agent_ keys_ with_ handle - Clears all unlocked keys from the specified agent handle.
- export_
key_ openssh_ pem - Exports the decrypted private key in OpenSSH PEM format.
- export_
key_ openssh_ pub - Exports the public key in OpenSSH
.pubformat. - get_
agent_ key_ count_ with_ handle - Returns the number of keys currently loaded in the specified agent handle.
- load_
keys_ into_ agent_ with_ handle - Loads specific keys (by alias) from secure storage into the specified agent handle.
- register_
keys_ with_ macos_ agent_ with_ handle - Stub function for non-macOS platforms.
- rotate_
key - Rotates the keypair for a given alias in the secure storage only.
- start_
agent_ listener - Starts the SSH agent listener on the specified Unix domain socket path.
- start_
agent_ listener_ with_ handle - Starts the SSH agent listener using the provided
AgentHandle.