#[non_exhaustive]pub enum NamespaceVerifyError {
UnsupportedEcosystem {
ecosystem: String,
},
PackageNotFound {
ecosystem: Ecosystem,
package_name: String,
},
OwnershipNotConfirmed {
ecosystem: Ecosystem,
package_name: String,
},
ChallengeExpired,
InvalidToken {
reason: String,
},
InvalidPackageName {
name: String,
reason: String,
},
NetworkError {
message: String,
},
RateLimited {
ecosystem: Ecosystem,
},
}Expand description
Errors from namespace verification operations.
Usage:
ⓘ
match result {
Err(NamespaceVerifyError::UnsupportedEcosystem { .. }) => { /* unknown ecosystem */ }
Err(NamespaceVerifyError::OwnershipNotConfirmed { .. }) => { /* user is not owner */ }
Err(e) => return Err(e.into()),
Ok(proof) => { /* proceed with proof */ }
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedEcosystem
The requested ecosystem is not supported.
PackageNotFound
The package was not found in the upstream registry.
Fields
OwnershipNotConfirmed
Ownership could not be confirmed via the upstream registry.
ChallengeExpired
The verification challenge has expired.
InvalidToken
The verification token is invalid.
InvalidPackageName
The package name is invalid.
NetworkError
A network error occurred during verification.
RateLimited
The upstream registry returned a rate limit response.