Network port and DID resolution.
Structs
- Registry
Response - Response from a registry POST operation.
Enums
- Network
Error - Domain error for outbound network operations.
- Resolution
Error - Domain error for identity resolution operations.
- Resolved
Identity - Cryptographic material resolved from a decentralized identifier.
Traits
- Identity
Resolver - Resolves a decentralized identifier to its current cryptographic material.
- Registry
Client - Fetches and pushes data to a remote registry service.
- Witness
Client - Submits key events and queries receipts from the witness infrastructure.