Module signing

Module signing 

Signing abstractions and DID resolution.

Structs

CachedPassphraseProvider
A PassphraseProvider that caches passphrases from an inner provider.
CallbackPassphraseProvider
A PassphraseProvider that delegates to a callback function.
KeychainPassphraseProvider
A PassphraseProvider that wraps an inner provider with OS keychain caching.
PrefilledPassphraseProvider
Provides a pre-collected passphrase for headless and automated environments.
StorageSigner
Concrete implementation of SecureSigner that uses a KeyStorage backend.
UnifiedPassphraseProvider
A passphrase provider that prompts exactly once regardless of how many distinct prompt messages are presented. Every call after the first is a cache hit. Designed for multi-key operations (e.g. device link) where the same passphrase protects all keys in the operation.

Enums

DidResolverError
Error type for DID resolution.
ResolvedDid
Result of DID resolution, parameterised by method.

Traits

DidResolver
Resolves a Decentralized Identifier (DID) to its cryptographic material.
PassphraseProvider
A trait for components that can securely provide a passphrase when requested.
SecureSigner
A trait for components that can perform signing operations using stored keys, identified by an alias, while securely handling decryption and passphrase input.