Signing abstractions and DID resolution.
Structs
- Cached
Passphrase Provider - A
PassphraseProviderthat caches passphrases from an inner provider. - Callback
Passphrase Provider - A
PassphraseProviderthat delegates to a callback function. - Keychain
Passphrase Provider - A
PassphraseProviderthat wraps an inner provider with OS keychain caching. - Prefilled
Passphrase Provider - Provides a pre-collected passphrase for headless and automated environments.
- Storage
Signer - Concrete implementation of
SecureSignerthat uses aKeyStoragebackend. - Unified
Passphrase Provider - A passphrase provider that prompts exactly once regardless of how many distinct prompt messages are presented. Every call after the first is a cache hit. Designed for multi-key operations (e.g. device link) where the same passphrase protects all keys in the operation.
Enums
- DidResolver
Error - Error type for DID resolution.
- Resolved
Did - Result of DID resolution, parameterised by method.
Traits
- DidResolver
- Resolves a Decentralized Identifier (DID) to its cryptographic material.
- Passphrase
Provider - A trait for components that can securely provide a passphrase when requested.
- Secure
Signer - A trait for components that can perform signing operations using stored keys, identified by an alias, while securely handling decryption and passphrase input.